@@ -9,6 +9,8 @@
 # for starting programs
 from subprocess import Popen
 
+# basics, currently only for prefix
+import sys
 # For circles
 from math import sin, cos, pi
 # and parsing a command string into words for Popen
@@ -19,10 +21,14 @@ from os.path import join, isfile
 # and system independent home folder location
 from user import home
 
+# and a webbrowser
+import webbrowser
+
 # basic graphical stuff
-from PyQt4.QtGui import QWidget, QGridLayout, QCursor, QIcon, QLabel, QLineEdit, QPushButton, QKeySequence, QPolygon
+from PyQt4.QtGui import QWidget, QGridLayout, QVBoxLayout, QHBoxLayout, QCursor, QIcon, QLabel, QLineEdit, QPushButton, QKeySequence, QPolygon
 # basic definitions and datatypes
 from PyQt4.QtCore import Qt, QPointF, QPoint, SIGNAL, SLOT
+from PyQt4.QtWebKit import QWebView
 
 # Basics for KDE integration
 from PyKDE4.kdeui import KIconLoader, KAction, KActionCollection, KShortcut, KShapeGesture
@@ -60,6 +66,83 @@ MAX_TOOL_TIP_LENGTH = 100
 
 ### Window ###
 
+class ConfigWidget(QWidget):
+    """A widget for configuring pyRad."""
+    def __init__(self, parent=None):
+        QWidget.__init__(self, parent)
+        # first a layout
+        self.lay = QVBoxLayout()
+        self.setLayout(self.lay)
+        # now the config buttons, horizontally
+        self.config_layout = QHBoxLayout()
+        self.config_keyboard = QPushButton("Keyboard")
+        self.config_gestures = QPushButton("Gestures")
+        self.config_layout.addWidget(self.config_keyboard)
+        self.config_layout.addWidget(self.config_gestures)
+        self.lay.addLayout(self.config_layout)
+        # now a flattr line
+        self.flattr_layout = QHBoxLayout()
+        self.flattr_left = QLabel("""If you like
+              pyRad""")
+        self.flattr_left.setAlignment(Qt.AlignRight | Qt.AlignVCenter)
+        #self.flattr_left.setAlignment(Qt.Right)
+        self.flattr_right = QLabel("""Why don't you
+Flattr me? :)""")
+        # get the icon, either systemwide or local
+        loader = KIconLoader()
+        flattr_pix = loader.loadIcon(join(sys.prefix, "share", "pyrad", "Wikimedia_Flattr_Button.png"), 0)
+        if flattr_pix.isNull():
+            flattr_pix = loader.loadIcon(join("images", "Wikimedia_Flattr_Button.png"), 0)
+        ic = QIcon(flattr_pix) # for a QPushButten
+        self.flattr_icon = QPushButton()
+        self.flattr_icon.setIcon(ic)
+        self.flattr_layout.addWidget(self.flattr_left)
+        self.flattr_layout.addWidget(self.flattr_icon)
+        self.flattr_layout.addWidget(self.flattr_right)
+        self.lay.addLayout(self.flattr_layout)
+        self.pyrad_url = QLabel("^ <a href='http://draketo.de/light/english/pyrad'>http://draketo.de/light/english/pyrad</a> ^")
+        self.lay.addWidget(self.pyrad_url)
+
+        # connect signals
+        self.connect(self.flattr_icon, SIGNAL("clicked()"), self.openFlattrUrl)
+        self.connect(self.config_keyboard, SIGNAL("clicked()"), self.openShortcutConfig)
+        self.connect(self.config_gestures, SIGNAL("clicked()"), self.openGesturesConfig)
+
+    def openShortcutConfig(self):
+        """Open the Keyboard Shortcut config dialog"""
+        Popen(["kcmshell4", "keys"])
+
+    def openGesturesConfig(self):
+        """Open the Keyboard Shortcut config dialog"""
+        Popen(["kcmshell4", "khotkeys"])
+
+    def openFlattrUrl(self):
+        """Open the flattr Url for the pyrad."""
+        self.openUrl("http://flattr.com/thing/58752/pyRad-a-wheel-type-command-interface-for-KDE")
+    
+    def openUrl(self, url):
+        """open a given URL in the browser"""
+        webbrowser.open(url)
+
+class ConfigEditor(KDialog):
+    """edit the base config"""
+    def __init__(self, parent=None):
+        QWidget.__init__(self, parent)
+        # Add the ConfigWidget
+        self.main = ConfigWidget(self)
+        self.setMainWidget(self.main)
+        self.setCaption("configure the Rad")
+        
+    def config(self):
+        """Show and raise the config dialog."""
+        self.show()
+        self.raise_()
+        self.activateWindow()
+        # run it, but don’t do anything with the result. 
+        if self.exec_() == self.Accepted:
+            return
+        
+
 class ItemEditWidget(QWidget):
     def __init__(self, parent=None, icon="konqueror", action=None):
         QWidget.__init__(self, parent)
@@ -67,7 +150,7 @@ class ItemEditWidget(QWidget):
         self.lay = QGridLayout()
         self.setLayout(self.lay)
         # Now add a description text
-        self.description = QLabel("Edit the icon (KDE progam name) and the action (commandline input). To delete the item, just delete the action line (set to empty).")
+        self.description = QLabel("Edit the icon (KDE progam name) and the action (commandline input).")
         self.lay.addWidget(self.description, 0, 0, 1, 3)
         # Then add a text field with name        
         self.icon_label = QLabel("Icon:", self)
@@ -229,6 +312,8 @@ class Rad(QWidget):
 
         # Also we need an editor for the items. Call it with self.editor.exec(item).
         self.editor = ItemEditor(self)
+        # and a config editor
+        self.editor_config = ConfigEditor(self)
 
 
     def focusOutEvent(self, event):
@@ -260,9 +345,10 @@ class Rad(QWidget):
                 elif event.button() == Qt.RightButton and i != self.circle[0]:
                     self.editLabel(i)
                     break
-		elif event.button() == Qt.RightButton and i == self.circle[0]:
+                elif event.button() == Qt.RightButton and i == self.circle[0]:# and i.action is None: # only in the top wheel.
 		    # TODO: right-click on the middle item should show the options. 
 		    # currently we just don't edit it. 
+                    self.editor_config.config()
                     break
 		elif event.button() == Qt.MidButton:
                     self.addLabelAfter(i)
